==> nextcloud-18.0.4.tgz: nextcloud/apps/theming/l10n/ca.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "S'està carregant la previsualització...",
    "Saved" : "Desat",
    "Admin" : "Administrador",
    "a safe home for all your data" : "un lloc segur per a les vostres dades",
    "Name cannot be empty" : "El nom del fitxer no pot estar buit",
    "The given name is too long" : "El nom introduït és massa llarg",
    "The given web address is too long" : "L'adreça web proporcionada és massa llarga",
    "The given web address is not a valid URL" : "L'adreça web no és una URL vàlida",
    "The given legal notice address is too long" : "L'adreça d'avís legal és massa llarga",
    "The given legal notice address is not a valid URL" : "L'adreça proporcionada per notificacions no és una URL vàlida",
    "The given privacy policy address is too long" : "L'adreça de política de privadesa és massa llarga",
    "The given privacy policy address is not a valid URL" : "L'adreça proporcionada per a la política de privacitat no és una URL vàlida",
    "The given slogan is too long" : "L'eslògan proporcionat és massa llarg",
    "The given color is invalid" : "El color proporcionat no és vàlid",
    "The file was uploaded" : "S'ha carregat el fitxer",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El fitxer carregat supera la directiva upload_max_filesize a php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El fitxer carregat supera la directiva MAX_FILE_SIZE especificada al formulari HTML",
    "The file was only partially uploaded" : "El fitxer només es ha estat carregat parcialment",
    "No file was uploaded" : "No s'ha carregat cap fitxer",
    "Missing a temporary folder" : "Falta una carpeta temporal",
    "Could not write file to disk" : "No s’ha pogut escriure el fitxer al disc",
    "A PHP extension stopped the file upload" : "Una extensió de PHP ha aturat la càrrega del fitxer",
    "No file uploaded" : "No s'ha carregat cap fitxer",
    "Unsupported image type" : "Tipus d'imatge no compatible",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Ja esteu fent servir un tema propi. La configuració de l'aplicació s'hauria d'haver modificat.",
    "Theming" : "Aparença",
    "Legal notice" : "Avís legal",
    "Privacy policy" : "Política de privadesa",
    "Adjust the Nextcloud theme" : "Ajusta el tema de Nextcloud",
    "Open documentation" : "Obrir la documentació",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "L'aparença permet personalitzar fàcilment l'aspecte de la vostra web i dels clients. Això serà visible per a tots els usuaris.",
    "Name" : "Nom",
    "Reset to default" : "Restableix als valors predeterminats",
    "Web link" : "Enllaç web",
    "https://…" : "https://...",
    "Slogan" : "Eslògan",
    "Color" : "Color",
    "Logo" : "Logotip",
    "Upload new logo" : "Carrega un nou logotip",
    "Login image" : "Imatge d'inici de sessió",
    "Upload new login background" : "Carrega un nou fons d'inici de sessió",
    "Remove background image" : "Suprimeix la imatge de fons",
    "Advanced options" : "Paràmetres avançats",
    "Legal notice link" : "Enllaç a l'avís legal",
    "Privacy policy link" : "Enllaç a la política de privadesa",
    "Header logo" : "Logotip de capçalera",
    "Upload new header logo" : "Carrega un nou logotip de capçalera",
    "Favicon" : "Icona de web",
    "Upload new favicon" : "Carrega un nou favicon",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instal·leu l'extensió PHP de l'ImageMagick compatible amb imatges SVG per generar automàticament una icona de web a partir del logotip pujat i del color."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-19.0.7.tgz: nextcloud/apps/theming/l10n/ca.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "S'està carregant la previsualització...",
    "Saved" : "Desat",
    "Admin" : "Administrador",
    "a safe home for all your data" : "un lloc segur per a les vostres dades",
    "Name cannot be empty" : "El nom del fitxer no pot estar buit",
    "The given name is too long" : "El nom introduït és massa llarg",
    "The given web address is too long" : "L'adreça web proporcionada és massa llarga",
    "The given web address is not a valid URL" : "L'adreça web no és una URL vàlida",
    "The given legal notice address is too long" : "L'adreça d'avís legal és massa llarga",
    "The given legal notice address is not a valid URL" : "L'adreça proporcionada per notificacions no és una URL vàlida",
    "The given privacy policy address is too long" : "L'adreça de política de privadesa és massa llarga",
    "The given privacy policy address is not a valid URL" : "L'adreça proporcionada per a la política de privacitat no és una URL vàlida",
    "The given slogan is too long" : "L'eslògan proporcionat és massa llarg",
    "The given color is invalid" : "El color proporcionat no és vàlid",
    "The file was uploaded" : "S'ha carregat el fitxer",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El fitxer carregat supera la directiva upload_max_filesize a php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El fitxer carregat supera la directiva MAX_FILE_SIZE especificada al formulari HTML",
    "The file was only partially uploaded" : "El fitxer només es ha estat carregat parcialment",
    "No file was uploaded" : "No s'ha carregat cap fitxer",
    "Missing a temporary folder" : "Falta una carpeta temporal",
    "Could not write file to disk" : "No s’ha pogut escriure el fitxer al disc",
    "A PHP extension stopped the file upload" : "Una extensió de PHP ha aturat la càrrega del fitxer",
    "No file uploaded" : "No s'ha carregat cap fitxer",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Ja esteu fent servir un tema propi. La configuració de l'aplicació s'hauria d'haver modificat.",
    "Theming" : "Aparença",
    "Legal notice" : "Avís legal",
    "Privacy policy" : "Política de privadesa",
    "Adjust the Nextcloud theme" : "Ajusta el tema de Nextcloud",
    "Open documentation" : "Obre la documentació",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "L'aparença permet personalitzar fàcilment l'aspecte de la vostra web i dels clients. Això serà visible per a tots els usuaris.",
    "Name" : "Nom",
    "Reset to default" : "Restableix als valors predeterminats",
    "Web link" : "Enllaç web",
    "https://…" : "https://...",
    "Slogan" : "Eslògan",
    "Color" : "Color",
    "Logo" : "Logotip",
    "Upload new logo" : "Puja un logotip nou",
    "Login image" : "Imatge d'inici de sessió",
    "Upload new login background" : "Carrega un nou fons d'inici de sessió",
    "Remove background image" : "Suprimeix la imatge de fons",
    "Advanced options" : "Paràmetres avançats",
    "Legal notice link" : "Enllaç a l'avís legal",
    "Privacy policy link" : "Enllaç a la política de privadesa",
    "Header logo" : "Logotip de capçalera",
    "Upload new header logo" : "Puja un logotip de capçalera nou",
    "Favicon" : "Icona de web",
    "Upload new favicon" : "Carrega un nou favicon",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instal·leu l'extensió PHP de l'ImageMagick compatible amb imatges SVG per generar automàticament una icona de web a partir del logotip pujat i del color.",
    "Unsupported image type" : "Tipus d'imatge no compatible"
},
"nplurals=2; plural=(n != 1);");
